==============
 Specification
==============

The following is a high-level description of components in the CADF
specification. The basic component of the CADF specification are Events. The
full CADF specification document can be found here_. Additional details on the
CADF specification are accessible via the `DMTF CADF`_ page.

.. _here: http://dmtf.org/sites/default/files/standards/documents/DSP0262_1.0.0.pdf
.. _DMTF CADF: http://www.dmtf.org/standards/cadf

.. toctree::
   :maxdepth: 1

   events
   attachments
   credentials
   endpoints
   geolocations
   hosts
   identifiers
   measurements
   paths
   reasons
   reportersteps
   resources
   tags
   timestamps
   taxonomy
